import React, { FC } from "react";
import Grid from "@material-ui/core/Grid";
import Paper from "@material-ui/core/Paper";
import Typography from "@material-ui/core/Typography";
import Fab from "@material-ui/core/Fab";
import Refresh from "@material-ui/icons/Refresh";
import { makeStyles } from "@material-ui/styles";
import { Player } from "./Board";
import PlayerIcon from "./PlayerIcon";

type Props = {
    player: Player;
    winner?: Player;
    onRestart: () => void;
};

type StyleProps = Pick<Props, "winner">;

const useStyles = makeStyles({
    paper: {
        height: "100%",
        display: "flex",
        alignItems: "center",
        justifyContent: "center",
        backgroundColor: ({ winner }: StyleProps) =>
            winner ? "green" : "white",
    },
    text: {
        marginRight: 4,
        color: ({ winner }: StyleProps) => (winner ? "white" : "black"),
    },
});

const Status: FC<Props> = ({ player, winner, onRestart }) => {
    const classes = useStyles({ winner });
    return (
        <Grid item container>
            <Grid item xs={10}>
                <Paper className={classes.paper} square>
                    <Typography variant="h6" className={classes.text}>
                        {winner ? "Winner is:" : "Next player:"}
                    </Typography>
                    <PlayerIcon color={winner ? "white" : "black"}>
                        {winner ?? player}
                    </PlayerIcon>
                </Paper>
            </Grid>
            <Grid item xs={2}>
                <Fab onClick={onRestart}>
                    <Refresh />
                </Fab>
            </Grid>
        </Grid>
    );
};

export default Status;
